@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# $Id: hash_test.sh,v 1.5 2001/01/21 19:30:36 nmav Exp $
+# $Id: hash_test.sh,v 1.10 2001/10/27 09:42:22 nmav Exp $
 
 if (echo "testing\c"; echo 1,2,3) | grep c >/dev/null; then
   if (echo $ac_n testing; echo 1,2,3) | sed s/-n/xn/ | grep xn >/dev/null; then
@@ -21,12 +21,12 @@ test_hash ( ) {
 	
 	plainlen=`echo $ac_n "$2$ac_c" | wc -c`
 	
-	got=`echo $ac_n "$2$ac_c" | ./driver $1 $plainlen`
+	got=`echo $ac_n "$2$ac_c" | ./driver $1 $plainlen | tr "[:lower:]" "[:upper:]"`
 
-	want=`echo $ac_n "$3$ac_c" | tr a-z A-Z`
+	want=`echo $ac_n "$3$ac_c" | tr "[:lower:]" "[:upper:]"`
 	
 	if test "$got" = ""; then
-		echo "This algorithm($1) may not available"
+		echo "This algorithm($1) might not available"
 	else
 		if test "$got" != "$want" ; then
 			echo "  -- TEST FAILED: $1 \"$2\""
@@ -95,15 +95,15 @@ echo
 
 
 echo $ac_n "testing RIPEMD160 $ac_c"
-test_hash 5 "" 9c1185a5c5e9fc54612808977ee8f548b2258d31
-test_hash 5 a 0bdc9d2d256b3ee9daae347be6f4dc835a467ffe
-test_hash 5 abc 8eb208f7e05d987a9b044a8e98c6b087f15a0bfc
-test_hash 5 "message digest" 5d0689ef49d2fae572b881b123a85ffa21595f36
-test_hash 5 abcdefghijklmnopqrstuvwxyz f71c27109c692c1b56bbdceb5b9d2865b3708dbc
+test_hash 5 "" 9C1185A5C5E9FC54612808977EE8F548B2258D31
+test_hash 5 a 0BDC9D2D256B3EE9DAAE347BE6F4DC835A467FFE
+test_hash 5 abc 8EB208F7E05D987A9B044A8E98C6B087F15A0BFC
+test_hash 5 "message digest" 5D0689EF49D2FAE572B881B123A85FFA21595F36
+test_hash 5 abcdefghijklmnopqrstuvwxyz F71C27109C692C1B56BBDCEB5B9D2865B3708DBC
 test_hash 5 abcdbcdecdefdefgefghfghighijhijkijkljklmklmnlmnomnopnopq \
-		12a053384a9c0c88e405a06c27dcf49ada62eb2b
+		12A053384A9C0C88E405A06C27DCF49ADA62EB2B
 test_hash 5 ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789 \
-		b0e20b6e3116640286ed3a87a5713079b21f5189
+		B0E20B6E3116640286ED3A87A5713079B21F5189
 echo ""
 
 
@@ -149,13 +149,19 @@ test_hash 8 "Suppose the original message has length = 50 bytes" \
 echo ""
 
 echo $ac_n "testing MD4 $ac_c"
-test_hash 16 "" 31d6cfe0d16ae931b73c59d7e0c089c0
-test_hash 16 a bde52cb31de33e46245e05fbdbd6fb24
-test_hash 16 abc a448017aaf21d8525fc10ae87aa6729d
-test_hash 16 "message digest" d9130a8164549fe818874806e1c7014b
-test_hash 16 abcdefghijklmnopqrstuvwxyz d79e1c308aa5bbcdeea8ed63df412da9
+test_hash 16 "" 31D6CFE0D16AE931B73C59D7E0C089C0
+test_hash 16 a BDE52CB31DE33E46245E05FBDBD6FB24
+test_hash 16 abc A448017AAF21D8525FC10AE87AA6729D
+test_hash 16 "message digest" D9130A8164549FE818874806E1C7014B
+test_hash 16 abcdefghijklmnopqrstuvwxyz D79E1C308AA5BBCDEEA8ED63DF412DA9
 test_hash 16 12345678901234567890123456789012345678901234567890123456789012345678901234567890 \
-		e33b4ddc9c38f2199c3e7b164fcc0536
+		E33B4DDC9C38F2199C3E7B164FCC0536
+echo ""
+
+echo $ac_n "testing SHA-256 $ac_c"
+test_hash 17 abc ba7816bf8f01cfea414140de5dae2223b00361a396177a9cb410ff61f20015ad
+test_hash 17 abcdbcdecdefdefgefghfghighijhijkijkljklmklmnlmnomnopnopq 248d6a61d20638b8e5c026930c3e6039a33ce45964ff2167f6ecedd419db06c1
+test_hash 17 abcdefghbcdefghicdefghijdefghijkefghijklfghijklmghijklmnhijklmnoijklmnopjklmnopqklmnopqrlmnopqrsmnopqrstnopqrstu cf5b16a778af8380036ce59e7b0492370b249b11e8f07a51afac45037afee9d1
 echo ""
 
 
